@@ -375,20 +375,48 @@ class Contact(models.Model):
         return '{} {}'.format(self.first_name,
                               self.last_name if self.last_name else '')
 
-    first_name = models.TextField(blank=True, null=True, max_length=30)
-    last_name = models.TextField(blank=True, null=True, max_length=30)
+    first_name = models.CharField(blank=True, null=True, max_length=30)
+    last_name = models.CharField(blank=True, null=True, max_length=30)
+    title = models.CharField(blank=True, null=True, max_length=50)
     company = models.ForeignKey(
         'Company', null=True, on_delete=models.CASCADE)
 
+    @property
+    def default_email_address(self):
+        return self.contactcommunication_set.filter(
+            default_flag=True, type_id__email_flag=True).first()
+
+    @property
+    def default_phone_number(self):
+        return self.contactcommunication_set.filter(
+            default_flag=True, type_id__phone_flag=True).first()
+
+    @property
+    def default_phone_ext(self):
+        phone = self.contactcommunication_set.filter(
+            default_flag=True, type_id__phone_flag=True).first()
+        return phone.extension if phone else None
+
+    @property
+    def default_fax_number(self):
+        return self.contactcommunication_set.filter(
+            default_flag=True, type_id__fax_flag=True).first()
+
 
 class ContactCommunication(models.Model):
     contact = models.ForeignKey(
         'Contact', null=True, on_delete=models.CASCADE)
     value = models.CharField(blank=True, null=True, max_length=250)
+    extension = models.CharField(blank=True, null=True, max_length=15)
     default_flag = models.BooleanField(blank=True, null=True)
     type = models.ForeignKey(
         'CommunicationType', null=True, on_delete=models.SET_NULL)
 
+    def __str__(self):
+        # Do not change this __str__ definition without good reason,
+        # email templates rely on it being the value.
+        return self.value
+
 
 class CommunicationType(models.Model):
     description = models.CharField(blank=False, null=False, max_length=250)
@@ -868,6 +896,10 @@ class TimeEntry(models.Model):
 
         return entered_time
 
+    @property
+    def note(self):
+        return self.notes
+
 
 class AvailableBoardTeamManager(models.Manager):
     """Return only teams whose ConnectWise board is active."""
@@ -1618,6 +1650,13 @@ class ServiceNote(TimeStampedModel):
     def __str__(self):
         return 'Ticket {} note: {}'.format(self.ticket, str(self.date_created))
 
+    def get_entered_time(self):
+        return self.date_created
+
+    @property
+    def note(self):
+        return self.text
+
 
 class Sla(TimeStampedModel, SlaGoalsMixin):
 
